@@ -1,7 +1,6 @@
 """This modules provides Node class that has tree structure."""
 import inspect
 from dataclasses import dataclass, field
-from functools import lru_cache
 from typing import Any, Iterator, List, Optional
 
 from mkapi.core.base import Base, Object
@@ -22,8 +21,8 @@ class Node(Tree):
         members: Member Node instances.
     """
 
-    parent: Optional["Node"] = field(default=None, init=False)
-    members: List["Node"] = field(init=False)
+    parent: Optional["Node"] = field(default=None, init=False, repr=False)
+    members: List["Node"] = field(init=False, repr=False)
     sourcefile_index: int = 0
 
     def __post_init__(self):
@@ -128,7 +127,7 @@ def get_kind(obj) -> str:
     return ""
 
 
-def is_member(name: str, obj: Any, sourcefiles: List[str]) -> int:
+def is_member(obj: Any, name: str = "", sourcefiles: List[str] = None) -> int:
     """Returns an integer thats indicates if `obj` is a member or not.
 
     * $-1$ : Is not a member.
@@ -143,6 +142,8 @@ def is_member(name: str, obj: Any, sourcefiles: List[str]) -> int:
             those of the superclasses should be included in the order
             of `mro()`.
     """
+    if name == "":
+        name = obj.__name__
     if isinstance(obj, property):
         obj = obj.fget
     if name in ["__func__", "__self__"]:
@@ -177,7 +178,7 @@ def get_members(obj: Any) -> List[Node]:
     sourcefiles = get_sourcefiles(obj)
     members = []
     for name, obj in inspect.getmembers(obj):
-        sourcefile_index = is_member(name, obj, sourcefiles)
+        sourcefile_index = is_member(obj, name, sourcefiles)
         if sourcefile_index != -1 and not from_object(obj):
             member = get_node(obj, recursive, sourcefile_index)
             if member.docstring:
@@ -185,11 +186,6 @@ def get_members(obj: Any) -> List[Node]:
     return sorted(members, key=lambda x: (-x.sourcefile_index, x.lineno))
 
 
-@lru_cache(maxsize=1000)
-def _get_node(obj, recursive, sourcefile_index) -> Node:
-    return Node(obj, recursive, sourcefile_index)
-
-
 def get_node(name, recursive: bool = True, sourcefile_index: int = 0) -> Node:
     """Returns a Node instace by name or object.
 
@@ -203,4 +199,4 @@ def get_node(name, recursive: bool = True, sourcefile_index: int = 0) -> Node:
     else:
         obj = name
 
-    return _get_node(obj, recursive, sourcefile_index)
+    return Node(obj, recursive, sourcefile_index)
