@@ -4,13 +4,13 @@ from dataclasses import InitVar, dataclass, field
 from typing import Iterator, List
 
 from mkapi import utils
+from mkapi.core import postprocess
 from mkapi.core.base import Base, Section
 from mkapi.core.inherit import inherit_by_filters
 from mkapi.core.linker import resolve_link
 from mkapi.core.node import Node, get_node
 from mkapi.core.regex import MKAPI_PATTERN, NODE_PATTERN, node_markdown
 from mkapi.core.renderer import renderer
-from mkapi.core import postprocess
 
 
 @dataclass
@@ -29,9 +29,9 @@ class Page:
 
     source: InitVar[str]
     abs_src_path: str
-    abs_api_paths: List[str] = field(default_factory=list)
-    markdown: str = field(init=False)
-    nodes: List[Node] = field(default_factory=list, init=False)
+    abs_api_paths: List[str] = field(default_factory=list, repr=False)
+    markdown: str = field(init=False, repr=False)
+    nodes: List[Node] = field(default_factory=list, init=False, repr=False)
 
     def __post_init__(self, source):
         self.markdown = "\n\n".join(self.split(source))
@@ -76,7 +76,7 @@ class Page:
 
         def replace(match):
             node = self.nodes[int(match.group(1))]
-            filters = match.group(2).strip("|")
+            filters = match.group(2).split("|")
             node.set_html(match.group(3))
             return renderer.render(node, filters=filters)
 
