@@ -67,16 +67,17 @@ class Renderer:
 
         Args:
             object: Object instance.
-            heading: If True, object is written in a heading tag.
-            upper: If True, object is written in upper case letters.
+            filters: Filters.
         """
+        if filters is None:
+            filters = []
         context = linker.resolve_object(object.html)
-        if context["level"]:
+        if context.get("level"):
+            if object.kind in ["module", "package"]:
+                filters.append("plain")
             template = self.templates["object_heading"]
         else:
             template = self.templates["object_div"]
-        if filters is None:
-            filters = []
         return template.render(context, object=object, filters=filters)
 
     def render_object_member(self, name: str, url: str, signature: str) -> str:
